package App::IsGitSynced;
$App::IsGitSynced::VERSION = '1.0.3';
# ABSTRACT: script to find out if the local git repos are fully synced


1;

__END__

=pod

=encoding UTF-8

=head1 NAME

App::IsGitSynced - script to find out if the local git repos are fully synced

=head1 VERSION

version 1.0.3

=head1 SYNOPSIS

Please read L<is_git_synced> documentation.

=head1 DESCRIPTION

App::IsGitSynced version numbers uses Semantic Versioning standart.
Please visit L<http://semver.org/> to find out all about this great thing.

=head1 SEE ALSO

=over

=item L<App::GitWorkspaceScanner>

=back

=head1 AUTHOR

Ivan Bessarabov <ivan@bessarabov.ru>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2012 by Ivan Bessarabov.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
